import React, { useMemo, useState } from 'react'
import { Input, Checkbox, Row, Col, message } from 'antd'
import Drag from '../../../../components/Drag'
import {
  LoadLedgers,
  ReloadTableFields,
  QueryFields,
  getMaplayerByTerminalType,
  GetLayerList,
  GetLayerFields,
  GetLayersShareField
} from '../../../../../apis/process'

const TaskFieldList = (props) => {

  const { title, value, addons, onChange, schema } = props
  const { service, layerName, accountName, tableName } = addons.formData || {}

  const [visible, setVisible] = useState(false)
  const [GISField, setGISField] = useState([])
  const [AccountField, setAccountField] = useState([])
  const [GISCheck, setGISCheck] = useState([])
  const [AccCheck, setAccCheck] = useState([])

  const getGISField = async () => {
    const { code, data } = await GetLayersShareField({ mapServer: service, layerNames: layerName })
    if (code === '0') {
      setGISField(data || [])
    }
  }

  const getAccountField = async () => {
    const { code, data } = await ReloadTableFields({ tableName: tableName })
    if (code === 0) {
      setAccountField(data?.root)
    }
  }

  const inputClick = () => {
    console.log(service, layerName, tableName)
    if (!service || !layerName || !tableName) {
      return message.error('请配置字段映射中的配置')
    }
    setGISCheck(value?.filter(v => v.fieldType === 'gis').map(v => v.fieldName) || [])
    setAccCheck(value?.filter(v => v.fieldType === '台账').map(v => v.fieldName) || [])
    getGISField()
    if (schema.$id === 'fieldList') {
      getAccountField()
    }
    setVisible(true)
  }

  const GISChange = (value) => {
    setGISCheck(value)
  }

  const AccChange = (value) => {
    setAccCheck(value)
  }

  const onOk = () => {
    let array = []
    if (GISField.length) {
      GISCheck?.forEach(v => {
        let fieldAliasName = GISField.find(s => s.fieldName === v)?.fieldAliasName || v
        array.push({ fieldName: v, fieldAliasName: fieldAliasName, fieldType: 'gis', })
      })
    }
    if (AccountField.length) {
      AccCheck?.forEach(v => {
        let fieldAliasName = AccountField.find(s => s.name === v)?.alias || v
        array.push({ fieldName: v, fieldAliasName: fieldAliasName, fieldType: '台账', })
      })
    }
    onChange(array)
    setVisible(false)
  }

  return (
    <div>
      <Input value={value?.map(v => v.fieldName)?.join(',')} onClick={inputClick} />
      <Drag
        title={title || '前端显示字段'}
        onOk={onOk}
        onCancel={() => setVisible(false)}
        visible={visible}
      >
        <div>
          <Checkbox.Group style={{ width: '100%', display: GISField.length ? 'block' : 'none' }} value={GISCheck} onChange={GISChange}>
            <div>GIS字段</div>
            <Row>
              {
                GISField.map(v => {
                  return (
                    <Col span={8} key={v.fieldName}>
                      <Checkbox value={v.fieldName}>{v.fieldAliasName}</Checkbox>
                    </Col>
                  )
                })
              }
            </Row>
          </Checkbox.Group>
          <Checkbox.Group style={{ width: '100%', display: AccountField.length ? 'block' : 'none' }} value={AccCheck} onChange={AccChange}>
            <div style={{ marginTop: '10px' }}>台账字段</div>
            <Row>
              {
                AccountField.map(v => {
                  return (
                    <Col span={8} key={v.name}>
                      <Checkbox value={v.name}>{v.alias}</Checkbox>
                    </Col>
                  )
                })
              }
            </Row>
          </Checkbox.Group>
        </div>
      </Drag>
    </div>
  )
}

export default TaskFieldList